Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/Remmina/Remmina.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAntenore Gatta (tmow) <antenore@simbiosi.org>2022-01-04 17:54:28 +0300
committerAntenore Gatta (tmow) <antenore@simbiosi.org>2022-01-04 17:54:28 +0300
commite5f27de6ad23f85dd1cfcd0ec560b2c54234c58a (patch)
tree35306363a51e74f5b198b0f47d9027e90838b4c9 /src/remmina_stats.c
parent310e6f98e789fd1b2381d5b2c1e0c1884f04598b (diff)
Remmina Hardening and Compliance
This Patch is meant to: - Enhance the use of the Primary Password - Replace the internal password hashing algorithm - Add an auditing log. This first commit adds some new settings in the Remmina preferences editor, and enhance the Primary Password functionalities. It's now possible to chose to lock Preferences (default), connections and edit actions (separately). Signed-off-by: Antenore Gatta (tmow) <antenore@simbiosi.org>
Diffstat (limited to 'src/remmina_stats.c')
-rw-r--r--src/remmina_stats.c20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/remmina_stats.c b/src/remmina_stats.c
index e4e93d401..bd5fb0464 100644
--- a/src/remmina_stats.c
+++ b/src/remmina_stats.c
@@ -114,8 +114,8 @@
* "ACTIVESECRETPLUGIN": {
* "plugin_name": "kwallet"
* }
- * "HASMASTERPASSWORD": {
- * "master_password_status": "OFF"
+ * "HASPRIMARYPASSWORD": {
+ * "primary_password_status": "OFF"
* }
*
* }
@@ -739,12 +739,12 @@ JsonNode *remmina_stats_get_secret_plugin()
}
/**
* Add a JSON member HASMASTERPASSWORD which shows the status of the master password.
*
* @return a JSON Node structure containing the status of the master password
*
*/
-JsonNode *remmina_stats_get_master_password_status()
+JsonNode *remmina_stats_get_primary_password_status()
{
TRACE_CALL(__func__);
@@ -754,8 +754,8 @@ JsonNode *remmina_stats_get_master_password_status()
b = json_builder_new();
json_builder_begin_object(b);
- json_builder_set_member_name(b, "master_password_status");
- if (remmina_pref_get_boolean("use_master_password")) {
+ json_builder_set_member_name(b, "primary_password_status");
+ if (remmina_pref_get_boolean("use_primary_password")) {
json_builder_add_string_value(b, "ON");
} else {
json_builder_add_string_value(b, "OFF");
@@ -771,7 +771,7 @@ JsonNode *remmina_stats_get_master_password_status()
/**
* Add a json member KIOSK which shows the status of the kiosk.
*
* @return a JSON Node structure containing the status of the master password
*
*/
JsonNode *remmina_stats_get_kiosk_mode()
@@ -854,8 +854,8 @@ JsonNode *remmina_stats_get_all()
json_builder_set_member_name(b, "ACTIVESECRETPLUGIN");
json_builder_add_value(b, n);
- n = remmina_stats_get_master_password_status();
- json_builder_set_member_name(b, "HASMASTERPASSWORD");
+ n = remmina_stats_get_primary_password_status();
+ json_builder_set_member_name(b, "HASPRIMARYPASSWORD");
json_builder_add_value(b, n);
n = remmina_stats_get_kiosk_mode();
@@ -739,12 +739,12 @@ JsonNode *remmina_stats_get_secret_plugin()
}
/**
- * Add a JSON member HASMASTERPASSWORD which shows the status of the master password.
+ * Add a JSON member HASPRIMARYPASSWORD which shows the status of the master password.
*
@@ -739,12 +739,12 @@ JsonNode *remmina_stats_get_secret_plugin()
*
- * @return a JSON Node structure containing the status of the master password
+ * @return a JSON Node structure containing the status of the primary password
*
*/
@@ -771,7 +771,7 @@ JsonNode *remmina_stats_get_master_password_status()
* Add a json member KIOSK which shows the status of the kiosk.
*
- * @return a JSON Node structure containing the status of the master password
+ * @return a JSON Node structure containing the status of the primary password
*
*/